"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.infraAwsDockerImageCli = exports.getRepo = exports.getDeploymentState = exports.deploy = exports.getConfigSchema = void 0;
const configSchema_json_1 = __importDefault(require("./schemas/configSchema.json"));
const utils_terraform_aws_1 = require("@goldstack/utils-terraform-aws");
const utils_sh_1 = require("@goldstack/utils-sh");
const utils_git_1 = require("@goldstack/utils-git");
const utils_docker_1 = require("@goldstack/utils-docker");
const utils_aws_cli_1 = require("@goldstack/utils-aws-cli");
const infra_aws_1 = require("@goldstack/infra-aws");
const infra_1 = require("@goldstack/infra");
const getConfigSchema = () => configSchema_json_1.default;
exports.getConfigSchema = getConfigSchema;
const deploy = async (config, deployment) => {
    const deploymentState = (0, infra_1.readDeploymentState)('./', deployment.name, {
        createIfNotExist: true,
    });
    const repoUrl = (0, infra_1.readTerraformStateVariable)(deploymentState, 'repo_url');
    (0, utils_docker_1.assertDocker)();
    const ecrLoginPassword = (await (0, utils_aws_cli_1.awsCli)({
        credentials: await (0, infra_aws_1.getAWSUser)(deployment.awsUser),
        region: deployment.awsRegion,
        command: `ecr get-login-password --region ${deployment.awsRegion}`,
        options: {
            silent: true,
        },
    })).trim();
    (0, utils_sh_1.exec)(`docker login --username AWS --password ${ecrLoginPassword} ${repoUrl}`);
    let commitHash = undefined;
    try {
        commitHash = (0, utils_git_1.hash)();
    }
    catch (e) {
        console.warn(`Cannot determine commit hash for tagging docker image: ${e}`);
    }
    if (!commitHash) {
        (0, utils_sh_1.exec)(`docker image tag ${config.configuration.imageTag} ${repoUrl}`);
        (0, utils_sh_1.exec)(`docker push ${repoUrl}`);
        deploymentState['latest'] = `${repoUrl}:latest`;
    }
    else {
        (0, utils_sh_1.exec)(`docker image tag ${config.configuration.imageTag}:${commitHash} ${repoUrl}:${commitHash}`);
        (0, utils_sh_1.exec)(`docker image tag ${config.configuration.imageTag}:${commitHash} ${repoUrl}:latest`);
        (0, utils_sh_1.exec)(`docker push ${repoUrl}:${commitHash}`);
        (0, utils_sh_1.exec)(`docker push ${repoUrl}:latest`);
        deploymentState['latest'] = `${repoUrl}:${commitHash}`;
    }
    (0, infra_1.writeDeploymentState)('./', deploymentState);
};
exports.deploy = deploy;
const getDeploymentState = (deploymentName, 
// eslint-disable-next-line @typescript-eslint/no-explicit-any
deploymentsState) => {
    let state;
    if (deploymentsState) {
        state = (0, infra_1.getDeploymentState)((0, infra_1.validateDeploymentsState)(deploymentsState), deploymentName);
    }
    else {
        state = (0, infra_1.readDeploymentState)('./', deploymentName);
    }
    return state;
};
exports.getDeploymentState = getDeploymentState;
const getRepo = (deploymentName, 
// eslint-disable-next-line @typescript-eslint/no-explicit-any
deploymentsState) => {
    const state = (0, exports.getDeploymentState)(deploymentName, deploymentsState);
    return (0, infra_1.readTerraformStateVariable)(state, 'repo_url');
};
exports.getRepo = getRepo;
const infraAwsDockerImageCli = async (config, deployment, args) => {
    if (args.length < 1) {
        throw new Error('Please provide the operation in the arguments: "up", "init", "plan", "apply", "deploy", "destroy", "upgrade", "terraform".');
    }
    const [operation] = args;
    if (operation === 'deploy') {
        await (0, exports.deploy)(config, deployment);
        return;
    }
    await (0, utils_terraform_aws_1.terraformAwsCli)(args);
};
exports.infraAwsDockerImageCli = infraAwsDockerImageCli;
//# sourceMappingURL=infraAwsDockerImage.js.map