"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.getDeployment = exports.getConfig = exports.getLogs = exports.startTask = exports.runTask = exports.getDeploymentState = exports.getRepo = void 0;
const utils_cli_1 = require("@goldstack/utils-cli");
const infraAwsDockerImage_1 = require("./infraAwsDockerImage");
var infraAwsDockerImage_2 = require("./infraAwsDockerImage");
Object.defineProperty(exports, "getRepo", { enumerable: true, get: function () { return infraAwsDockerImage_2.getRepo; } });
Object.defineProperty(exports, "getDeploymentState", { enumerable: true, get: function () { return infraAwsDockerImage_2.getDeploymentState; } });
const apiDockerImageAws_1 = require("./apiDockerImageAws");
const yargs_1 = __importDefault(require("yargs"));
const utils_package_1 = require("@goldstack/utils-package");
const utils_terraform_1 = require("@goldstack/utils-terraform");
const utils_package_config_1 = require("@goldstack/utils-package-config");
var apiDockerImageAws_2 = require("./apiDockerImageAws");
Object.defineProperty(exports, "runTask", { enumerable: true, get: function () { return apiDockerImageAws_2.runTask; } });
Object.defineProperty(exports, "startTask", { enumerable: true, get: function () { return apiDockerImageAws_2.startTask; } });
Object.defineProperty(exports, "getLogs", { enumerable: true, get: function () { return apiDockerImageAws_2.getLogs; } });
const getConfig = () => {
    const packageConfig = new utils_package_config_1.PackageConfig({
        packagePath: './',
    });
    return packageConfig.getConfig();
};
exports.getConfig = getConfig;
const getDeployment = (deploymentName) => {
    const packageConfig = new utils_package_config_1.PackageConfig({
        packagePath: './',
    });
    return packageConfig.getDeployment(deploymentName);
};
exports.getDeployment = getDeployment;
const imageCommands = () => {
    const deploymentPositional = (yargs) => {
        return yargs.positional('deployment', {
            type: 'string',
            describe: 'Name of the deployment this command should be applied to',
            demandOption: true,
        });
    };
    return (yargs) => {
        return yargs
            .command('run <deployment>', 'Runs the image', deploymentPositional)
            .command('start <deployment>', 'Starts the image', deploymentPositional)
            .command('logs <taskId>', 'Prints the logs for an image', (yargs) => {
            return yargs.positional('taskId', {
                type: 'string',
                describe: 'Id of the tasks for which logs should be obtained.',
                demandOption: true,
            });
        });
    };
};
const run = async (args) => {
    await (0, utils_cli_1.wrapCli)(async () => {
        const argv = await (0, utils_package_1.buildCli)({
            yargs: yargs_1.default,
            deployCommands: (0, utils_package_1.buildDeployCommands)(),
            infraCommands: (0, utils_terraform_1.infraCommands)(),
        })
            .command('image', 'Commands for working with images.', imageCommands())
            .help()
            .parse();
        const packageConfig = new utils_package_config_1.PackageConfig({
            packagePath: './',
        });
        const config = packageConfig.getConfig();
        const command = argv._[0];
        const [, , , ...opArgs] = args;
        if (command === 'infra') {
            const deploymentName = opArgs[1];
            const deployment = packageConfig.getDeployment(deploymentName);
            await (0, infraAwsDockerImage_1.infraAwsDockerImageCli)(config, deployment, opArgs);
            return;
        }
        if (command === 'deploy') {
            const deploymentName = opArgs[0];
            const deployment = packageConfig.getDeployment(deploymentName);
            await (0, infraAwsDockerImage_1.infraAwsDockerImageCli)(config, deployment, ['deploy', ...opArgs]);
            return;
        }
        if (command === 'image') {
            const deploymentName = opArgs[1];
            const deployment = packageConfig.getDeployment(deploymentName);
            await (0, apiDockerImageAws_1.apiDockerImageAwsCli)(config, deployment, opArgs);
            return;
        }
        throw new Error('Unknown command: ' + command);
    });
};
exports.run = run;
//# sourceMappingURL=templateDockerImageAws.js.map